@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20200220';
+$CPAN::Perl::Releases::VERSION = '5.20200820';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -252,6 +252,19 @@ our $data =
 "5.31.7" => { id => 'ATOOMIC' },
 "5.31.8" => { id => 'WOLFSAGE' },
 "5.31.9" => { id => 'RENEEB' },
+"5.30.2-RC1" => { id => 'SHAY' },
+"5.30.2" => { id => 'SHAY' },
+"5.31.10" => { id => 'XSAWYERX' },
+"5.31.11" => { id => 'XSAWYERX' },
+"5.32.0-RC0" => { id => 'XSAWYERX' },
+"5.28.3-RC1" => { id => 'XSAWYERX' },
+"5.28.3" => { id => 'XSAWYERX' },
+"5.30.3-RC1" => { id => 'XSAWYERX' },
+"5.30.3" => { id => 'XSAWYERX' },
+"5.32.0-RC1" => { id => 'XSAWYERX' },
+"5.32.0" => { id => 'XSAWYERX' },
+"5.33.0" => { id => 'XSAWYERX' },
+"5.33.1" => { id => 'ETHER' },
 };
 
 sub perl_tarballs {
@@ -320,7 +333,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20200220
+version 5.20200820
 
 =head1 SYNOPSIS
 
